==> OpenCL-0.8.5.tgz: OpenCL-0.8.5/include/dsa.h <==
/*************************************************
* DSA Header File                                *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#ifndef OPENCL_DSA_H__
#define OPENCL_DSA_H__

#include <opencl/bigint.h>
#include <opencl/pk_keys.h>
#include <opencl/mod_exp.h>
#include <opencl/dl_parm.h>

namespace OpenCL {

/*************************************************
* DSA Public Key                                 *
*************************************************/
class DSA_PublicKey : public PK_Verifying_wo_MR_Key
   {
   public:
      bool verify(const byte[], u32bit, const byte[], u32bit) const;

      u32bit max_input_bits() const { return q.bits(); }

      bool check_params() const;
      const BigInt& get_p() const { return p; }
      const BigInt& get_q() const { return q; }
      const BigInt& get_g() const { return g; }
      const BigInt& get_y() const { return y; }

      DSA_PublicKey(const DL_Group&, const BigInt&);

      // DEPRECATED FUNCTION
      DSA_PublicKey(const BigInt&, const BigInt&,
                    const BigInt&, const BigInt&);
   protected:
      DSA_PublicKey() {}
      BigInt p, q, g;
      BigInt y;
      FixedBase_Exp powermod_g_p, powermod_y_p;
      mutable BigInt t1, r, s;
   };

/*************************************************
* DSA Private Key                                *
*************************************************/
class DSA_PrivateKey : public DSA_PublicKey, public PK_Signing_Key
   {
   public:
      SecureVector<byte> sign(const byte[], u32bit) const;

      bool check_params() const;
      const BigInt& get_x() const { return x; }

      DSA_PrivateKey(const DL_Group&);
      DSA_PrivateKey(const DL_Group&, const BigInt&, const BigInt&);

      // DEPRECATED FUNCTIONS
      DSA_PrivateKey(u32bit, bool = false);
      DSA_PrivateKey(const BigInt&, const BigInt&, const BigInt&);
      DSA_PrivateKey(const BigInt&, const BigInt&, const BigInt&,
                     const BigInt&, const BigInt&);
      DSA_PrivateKey(const byte[], u32bit, u32bit = 1024, u32bit = 0);
      // END DEPRECATED FUNCTIONS
   private:
      bool valid_fips186_p_size(u32bit) const;
      void keygen_operation();
      BigInt x;
   };

}

#endif

==> OpenCL-0.8.7.tgz: OpenCL-0.8.7/include/dsa.h <==
/*************************************************
* DSA Header File                                *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#ifndef OPENCL_DSA_H__
#define OPENCL_DSA_H__

#include <opencl/bigint.h>
#include <opencl/pk_keys.h>
#include <opencl/mod_exp.h>
#include <opencl/dl_parm.h>

namespace OpenCL {

/*************************************************
* DSA Public Key                                 *
*************************************************/
class DSA_PublicKey : public PK_Verifying_wo_MR_Key
   {
   public:
      bool verify(const byte[], u32bit, const byte[], u32bit) const;

      u32bit max_input_bits() const { return q.bits(); }

      bool check_params() const;
      const BigInt& get_p() const { return p; }
      const BigInt& get_q() const { return q; }
      const BigInt& get_g() const { return g; }
      const BigInt& get_y() const { return y; }

      DSA_PublicKey(const DL_Group&, const BigInt&);
      DSA_PublicKey(const DSA_PublicKey&);
   protected:
      DL_Group group;
      const BigInt &p, &q, &g;
      BigInt y;
      FixedBase_Exp powermod_g_p, powermod_y_p;
   };

/*************************************************
* DSA Private Key                                *
*************************************************/
class DSA_PrivateKey : public DSA_PublicKey, public PK_Signing_Key
   {
   public:
      SecureVector<byte> sign(const byte[], u32bit) const;

      bool check_params() const;
      const BigInt& get_x() const { return x; }

      DSA_PrivateKey(const DL_Group&);
      DSA_PrivateKey(const DL_Group&, const BigInt&, const BigInt&);
   private:
      BigInt x;
   };

}

#endif
